@@ -1,8 +1,8 @@
-/*  $Id: SagasuApp.cpp,v 1.14 2003/10/22 19:52:35 sarrazip Exp $
+/*  $Id: SagasuApp.cpp,v 1.17 2005/08/09 00:11:28 sarrazip Exp $
     SagasuApp.cpp - Class representing the main window
 
     sagasu - GNOME tool to find strings in a set of files
-    Copyright (C) 2002, 2003 Pierre Sarrazin <http://sarrazip.com/>
+    Copyright (C) 2002-2004 Pierre Sarrazin <http://sarrazip.com/>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -112,7 +112,6 @@ result_page_button_press_cb(GtkWidget *text_view,
 			    gpointer data)
 {
     ResultPage *page = (ResultPage *) data;
-
     SagasuApp &app = SagasuApp::get_instance();
 
     if (e->button == 1 && e->type == GDK_2BUTTON_PRESS)
@@ -174,10 +173,13 @@ about_cb(GtkWidget *widget, gpointer data)
 
 	GdkPixbuf *logo = gdk_pixbuf_new_from_file(
 					logo_filename.c_str(), NULL); 
+	string copyright = string(
+	     "Copyright (C) 2002-2004 Pierre Sarrazin <http://sarrazip.com/>\n")
+			+ _("Distributed under the GNU General Public License");
 	dialog = gnome_about_new(_("Sagasu"), VERSION,
-			"(C) 2002, 2003 Pierre Sarrazin <http://sarrazip.com/>",
-			_("GNOME tool to find strings in a set of files"),
-			authors, NULL, NULL, logo);
+	    copyright.c_str(),
+	    _("GNOME tool to find strings in a set of files"),
+	    authors, NULL, NULL, logo);
 
 	gtk_window_set_transient_for(GTK_WINDOW(dialog), GTK_WINDOW(app));	
 	if (logo != NULL)
@@ -773,6 +775,8 @@ SagasuApp::search_cb(GtkWidget *, gpointer)
     if (target_expr.empty())
 	return;
 
+    string raw_target_expr = target_expr;
+
     string search_dir = latin1_string(gtk_entry_get_text(
 					GTK_ENTRY(search_dir_entry)));
     if (search_dir.empty())
@@ -809,6 +813,7 @@ SagasuApp::search_cb(GtkWidget *, gpointer)
     input_channel = NULL;
     create_search_process(
 			target_expr,
+			raw_target_expr,
 			search_dir,
 			get_file_patterns(),
 			match_case(),
@@ -890,6 +895,7 @@ SagasuApp::exclude_symlinked_dirs() const
 
 void
 SagasuApp::create_search_process(const string &target_expr,
+				const string &raw_target_expr,
 				const string &search_dir,
 				const string &file_patterns,
 				bool match_case,
@@ -998,9 +1004,12 @@ SagasuApp::create_search_process(const string &target_expr,
 	This is the parent.
 	Close the writing end of the pipe.
 	Remember in which page the results are to be written.
+	Start that page with the search string.
     */
     close(pipefds[1]);
     result_page_of_current_search = get_current_result_page();
+    result_page_of_current_search->insert_text(
+		    _("Search string:") + string(" ") + raw_target_expr + "\n");
     pending_input.erase();
 
     last_matching_filename.erase();
@@ -1054,17 +1063,16 @@ SagasuApp::close_input()
 void
 SagasuApp::show_num_matching_lines()
 {
-    const char *ml = _("Matching lines");
-    const char *mf = _("matching files");
-
-    char status[512];
+    if (result_page_of_current_search == NULL)
+	return;
+    char status[2048];
     snprintf(status, sizeof(status),
 	    "%s: %u; %s: %u %s",
-		ml, (unsigned) num_matching_lines,
-		mf, (unsigned) num_matching_files,
+		_("Matching lines"), (unsigned) num_matching_lines,
+		_("matching files"), (unsigned) num_matching_files,
 		(input_channel == NULL ? "" : _("(still searching)"))
 		);
-    get_current_result_page()->set_status_label(status);
+    result_page_of_current_search->set_status_label(status);
 }
 
 
@@ -1166,6 +1174,8 @@ SagasuApp::get_result_text_line_for_pos(gint pos_in_chars) const
 
     // Get the number (>=0) of the line that contains the desired position:
     gint line_num = gtk_text_iter_get_line(&it);
+    if (line_num == 0)  // first line shows search string; it is not a result
+	return "";
 
     // Get an iterator on the start of that line:
     GtkTextIter line_start_it;
